<?php
/**
 * Add Genericons
 *
 * @link https://genericons.com/
 *
 * @package Suri
 * @since 0.1.2
 */

/**
 * Fonts icons location and css classes.
 *
 * @since 0.1.8
 *
 * @param str $option name of the option.
 */
function suri_icon_fonts_array( $option ) {

	/**
	 * Filter fonts icons location and css classes.
	 *
	 * @since 0.1.8
	 */
	$font_icons = apply_filters(
		'suri_font_icons', array(
			'byline' => array(
				'location' => 'before',
				'class' => 'genericon genericon-user',
			),
			'posted-on' => array(
				'location' => 'before',
				'class' => 'genericon genericon-month',
			),
			'comments-link' => array(
				'location' => 'before',
				'class' => 'genericon genericon-comment',
			),
			'cat-links' => array(
				'location' => 'before',
				'class' => 'genericon genericon-category',
			),
			'sidebar-toggle' => array(
				'location' => 'before',
				'class' => 'font-toggle',
			),
			'edit-link' => array(
				'location' => 'before',
				'class' => 'genericon genericon-edit',
			),
			'menu-toggle' => array(
				'location' => 'before',
				'class' => 'genericon genericon-menu',
			),
			'search-form' => array(
				'location' => 'before',
				'class' => 'genericon genericon-search',
			),
			'tags-links' => array(
				'location' => 'before',
				'class' => 'genericon genericon-tag',
			),
		)
	);

	if ( 'all' === $option ) :
		return $font_icons;
	else :
		return $font_icons[ $option ];
	endif;
}

/**
 * Social icons css classes.
 *
 * @since 0.1.8
 *
 * @param str $option name of the option.
 */
function suri_social_icons_array( $option ) {

	/**
	 * Filter social icons css classes.
	 *
	 * @since 0.1.8
	 */
	$social_icons = apply_filters(
		'suri_social_icons', array(
			'facebook.com'           => 'genericon genericon-facebook-alt',
			'twitter.com'            => 'genericon genericon-twitter',
			'plus.google.com'        => 'genericon genericon-googleplus-alt',
			'youtube.com'            => 'genericon genericon-youtube',
			'linkedin.com'           => 'genericon genericon-linkedin',
			'mailto'                 => 'genericon genericon-mail',
			'instagram.com'          => 'genericon genericon-instagram',
			'github.com'             => 'genericon genericon-github',
			'pinterest.com'          => 'genericon genericon-pinterest',
			'skype.com'              => 'genericon genericon-skype',
			'skype:'                 => 'genericon genericon-skype',
			'feedburner.google.com'  => 'genericon genericon-feed',
			'feedburner.com'         => 'genericon genericon-feed',
			'/feed'                  => 'genericon genericon-feed',
			'?feed=rss2'             => 'genericon genericon-feed',
			'flickr.com'             => 'genericon genericon-flickr',
			'wordpress.org'          => 'genericon genericon-wordpress',
			'wordpress.com'          => 'genericon genericon-wordpress',
			'newsletter'             => 'genericon genericon-mail',
			'stumbleupon.com'        => 'genericon genericon-stumbleupon',
			'vimeo.com'              => 'genericon genericon-vimeo',
			'codepen.io'             => 'genericon genericon-codepen',
			'digg.com'               => 'genericon genericon-digg',
			'dribbble.com'           => 'genericon genericon-dribbble',
			'getpocket.com'          => 'genericon genericon-pocket',
			'polldaddy.com'          => 'genericon genericon-polldaddy',
			'reddit.com'             => 'genericon genericon-reddit',
			'spotify.com'            => 'genericon genericon-spotify',
			'tumblr.com'             => 'genericon genericon-tumblr',
			'twitch.tv'              => 'genericon genericon-twitch',
			'default'                => 'genericon genericon-star',
		)
	);

	if ( 'all' === $option ) :
		return $social_icons;
	else :
		return $social_icons[ $option ];
	endif;
}
