<?php
/**
 * Adds inline css to site head
 *
 * @package Suri
 * @since 0.0.1
 */

/**
 * Generate inline css.
 *
 * Collect portions of inline css from different functions and methods,
 * and enque them to site head.
 *
 * @since 0.0.8
 */
function suri_inline_css() {

	/**
	 * Filter inline css.
	 *
	 * @since 0.0.8
	 */
	$output = apply_filters( 'suri_get_inline_style', '' );

	if ( '' !== $output ) :

		/* Strip tags and remove breaks */
		$output = wp_strip_all_tags( $output, true );

		/* A bit of css minification */
		$to_be_replaced = array( ': ', '; ', ' {', ', ', ';}', ' + ' );
		$replace_with = array( ':', ';', '{', ',', '}', '+' );
		$output = str_replace( $to_be_replaced, $replace_with, $output );

		/* Enqueue inline css */
		wp_add_inline_style( 'suri-style', $output );
	endif;
}
add_action( 'wp_enqueue_scripts', 'suri_inline_css', 50 );

/**
 * Inline thumbnail css.
 *
 * Check thumbnail size and return css to either left align or center
 * align the thumbnail.
 *
 * @since 0.0.6
 *
 * @see suri_inline_css()
 *
 * @param str $output Css string.
 * @return string $output css string.
 */
function suri_thumb_css( $output ) {
	if ( is_singular() ) :
		return $output;
	endif;

	global $content_width;
	$thumb_size = suri_get_thumb_size();
	$width = absint( $thumb_size['w'] );
	$float = is_rtl() ? 'right' : 'left';
	$margin_dir = is_rtl() ? 'margin-left' : 'margin-right';
	if ( $width <= ( $content_width / 3 ) ) :
		if ( $width >= 220 ) {
			$min_width = intval( 2.5 * $width );
		} else {
			$min_width = 3 * $width;
		}

		$thumb_css = sprintf( '
		.thumbnails {
			float:%1$s;
			%2$s:1.5em;
			margin-bottom:0;
		}
		', $float, $margin_dir );
		$output .= sprintf( '
		@media only screen and (min-width: %1$spx) {
			%2$s
		}
		', $min_width, $thumb_css );
	elseif ( $width <= ( $content_width / 2 ) && $width >= 250 ) :
		$min_width = 2 * $width;
		$thumb_css = sprintf( '
		.thumbnails {
			float:%1$s;
			%2$s:1.5em;
			margin-bottom:0;
		}
		', $float, $margin_dir );
		$output .= sprintf( '
		@media only screen and (min-width: %1$spx) {
			%2$s
		}
		', $min_width, $thumb_css );
	else :
		$thumb_css = sprintf( '
		.thumbnails {
			float:none;
			margin-left:auto;
			margin-right:auto;
			margin-bottom:1.5em;
		}
		' );
		$output .= sprintf( '
		@media only screen and (min-width: 768px) {
			%s
		}
		', $thumb_css );
	endif;

	return $output;
}
add_filter( 'suri_get_inline_style', 'suri_thumb_css' );
